@@ -2,9 +2,13 @@
   op <- options()
   op_finbif <- list(
     # There are (or will be) multiple versions and locations of the FinBIF API
-    finbif_api_url = "api.laji.fi",
+    finbif_api_url = "https://api.laji.fi",
     finbif_api_version = "v0",
     finbif_warehouse_query = "warehouse/query/",
+    finbif_allow_query = TRUE,
+    finbif_rate_limit = 1,
+    finbif_max_queries = 2000L,
+    finbif_max_page_size = 1000L,
     finbif_use_cache = TRUE,
     finbif_tz = Sys.timezone(),
     finbif_locale = get_locale()
