@@ -3,7 +3,7 @@ if (has_dev_api()) {
   token <- Sys.getenv("FINBIF_ACCESS_TOKEN")
   Sys.setenv(FINBIF_ACCESS_TOKEN = Sys.getenv("FINBIF_DEV_ACCESS_TOKEN"))
 
-  options(finbif_api_url = "apitest.laji.fi")
+  options(finbif_api_url = "https://apitest.laji.fi")
 
   assignInNamespace("var_names", finbif:::var_names_test, "finbif")
 
@@ -13,7 +13,7 @@ if (has_dev_api()) {
 
   for (file in files) source(file, local = TRUE)
 
-  options(finbif_api_url = "api.laji.fi")
+  options(finbif_api_url = "https://api.laji.fi")
 
   Sys.setenv(FINBIF_ACCESS_TOKEN = token)
 
